@@ -1,10 +1,11 @@
 """Import commonly used items."""
 from .container import Container
-from .errors import ConfigError, ContainerError, Error
+from .errors import ConfigError, ContainerError, Error, TestError
 
 __all__ = [
     'ConfigError',
     'Container',
     'ContainerError',
     'Error',
+    'TestError',
 ]
