@@ -7,17 +7,6 @@ from clank import ArgumentCommand, HelpCommand, Manager, UsageCommand
 from copy import deepcopy
 
 
-def get_containers():
-    return sorted(Container.list(), key=lambda c: c.name)
-
-
-def get_container(name):
-    cnts = filter(lambda c: c.name == name, get_containers())
-    if cnts:
-        return cnts[0]
-    return None
-
-
 class InfoCommand(ArgumentCommand):
     """Print information about a container."""
     name = 'info'
@@ -65,6 +54,8 @@ class BuildCommand(ArgumentCommand):
                                     help="Do not use the Docker cache.")
         self.argparser.add_argument('-v', '--version', dest='version', nargs=1,
                                     help="The version of the container to build.")
+        self.argparser.add_argument('-V', '--verify', dest='verify', action='store_true',
+                                    help="Only build the container if it is verified.")
         self.argparser.add_argument('path', metavar='PATH', nargs='?',
                                     help="The path to the container to build.")
 
@@ -72,6 +63,9 @@ class BuildCommand(ArgumentCommand):
         self.parse_args(args)
         try:
             container = Container.from_path(path=self.options.path, version=self.options.version)
+            if self.options.verify and not container.is_verified():
+                print("{} is not verified".format(container.tag))
+                return 1
             container.build(self.options.prebuild, self.options.nocache)
             print("{} built".format(container.tag))
             if self.options.push:
@@ -90,6 +84,8 @@ class PushCommand(ArgumentCommand):
     def add_arguments(self):
         self.argparser.add_argument('-v', '--version', dest='version', nargs=1,
                                     help="The version of the container to build.")
+        self.argparser.add_argument('-V', '--verify', dest='verify', action='store_true',
+                                    help="Only push the container if it is verified.")
         self.argparser.add_argument('path', metavar='PATH', nargs='?',
                                     help="The path to the container to push.")
 
@@ -97,6 +93,9 @@ class PushCommand(ArgumentCommand):
         self.parse_args(args)
         try:
             container = Container.from_path(path=self.options.path, version=self.options.version)
+            if self.options.verify and not container.is_verified():
+                print("{} is not verified".format(container.tag))
+                return 1
             if not container.is_built():
                 container.build()
             container.push()
@@ -142,6 +141,8 @@ class RunCommand(ArgumentCommand):
                                     help="Run the container in the background.")
         self.argparser.add_argument('-v', '--version', dest='version', nargs=1,
                                     help="The version of the container to run.")
+        self.argparser.add_argument('-V', '--verify', dest='verify', action='store_true',
+                                    help="Only run the container if it is verified.")
         self.argparser.add_argument('path', metavar='PATH', nargs='?',
                                     help="The path to the container to run.")
 
@@ -149,6 +150,9 @@ class RunCommand(ArgumentCommand):
         self.parse_args(args)
         try:
             container = Container.from_path(path=self.options.path, version=self.options.version)
+            if self.options.verify and not container.is_verified():
+                print("{} is not verified".format(container.tag))
+                return 1
             if not container.is_built():
                 container.build()
                 print("{} built".format(container.tag))
@@ -188,6 +192,8 @@ class TestCommand(ArgumentCommand):
                                     help="Rebuild the test container before running.")
         self.argparser.add_argument('-v', '--version', dest='version', nargs=1,
                                     help="The version of the container to run.")
+        self.argparser.add_argument('-V', '--verify', dest='verify', action='store_true',
+                                    help="Only run the container if it is verified.")
         self.argparser.add_argument('path', metavar='PATH', nargs='?',
                                     help="The path to the container to run.")
 
@@ -195,6 +201,9 @@ class TestCommand(ArgumentCommand):
         self.parse_args(args)
         try:
             container = Container.from_path(path=self.options.path, version=self.options.version)
+            if self.options.verify and not container.is_verified():
+                print("{} is not verified".format(container.tag))
+                return 1
             if not container.is_built():
                 container.build()
                 print("{} built".format(container.tag))
