@@ -217,6 +217,7 @@ class Container(object):
                 'testing': self._get_fig_cfg(True),
                 'is-built': self.is_built(),
                 'is-running': self.is_running(),
+                'is-verified': self.is_verified(),
             }
             path = rel(cwd, self.path)
             if path and path != '.':
@@ -229,21 +230,6 @@ class Container(object):
     def to_config(self):
         """Return the container's configuration."""
 
-    def _exec(self, args, check=False, quiet=False):
-        """
-        Run an executable. If `check` is `True` raises a ContainerError on call failure. If `quiet`
-        is `False` then I/O is redirected to /dev/null.
-        """
-        if quiet:
-            with open(os.devnull, 'w') as devnull:
-                ret = subprocess.call(args, stderr=devnull, stdout=devnull, stdin=devnull)
-        else:
-            ret = subprocess.call(args)
-
-        if check and ret != 0:
-            raise ContainerError("exec failed for {}: {}".format(self.name, args))
-        return ret
-
     def _format(self, value):
         """
         Format a string value with the `user`, `name`, `version`, and `tag`. Keyword args may be
@@ -345,11 +331,33 @@ class Container(object):
         Return True if the container has been built previously. This does not guarantee that the
         existing image is up to date.
         """
-        with open(os.devnull, 'w') as devnull:
-            code = subprocess.call(['docker', 'inspect', self.tag],
-                                   cwd=self.path, stderr=devnull,
-                                   stdout=devnull, stdin=devnull)
-            return code == 0
+        try:
+            with open(os.devnull, 'w') as devnull:
+                code = subprocess.call(['docker', 'inspect', self.tag],
+                                       cwd=self.path, stderr=devnull,
+                                       stdout=devnull, stdin=devnull)
+                return code == 0
+        except OSError:
+            raise ContainerError("{} built check failed: docker is not available".format(self.tag))
+
+    def is_running(self):
+        """Return True if the container is running."""
+        try:
+            args = self._get_fig_args('ps', '-q')
+            out = subprocess.check_output(args, cwd=self.path).strip()
+            if out:
+                return True
+            return False
+        except subprocess.CalledProcessError:
+            msg = "{} running check failed: fig returned non-zero exit code"
+            raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} running check failed: fig is not available".format(self.tag))
+
+    def is_verified(self):
+        """Return True if this version of the container is verified."""
+        from .version import verify
+        return verify(self)
 
     def prebuild(self):
         """Execute container prebuild step."""
@@ -369,9 +377,10 @@ class Container(object):
         try:
             subprocess.check_call(["bash", "-c", cmd], cwd=self.path, env=env)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} prebuild failed: command failed".format(self.tag))
-        except KeyboardInterrupt:
-            raise ContainerError("{} prebuild failed: interrupted".format(self.tag))
+            msg = "{} prebuild failed: command returned non-zero exit code"
+            raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} prebuild failed: command is not available".format(self.tag))
 
     def build(self, prebuild=None, nocache=None):
         """
@@ -403,15 +412,20 @@ class Container(object):
         except subprocess.CalledProcessError:
             msg = "{} build failed: docker returned non-zero exit code"
             raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} build failed: docker is not available".format(self.tag))
 
     def push(self):
         """Push the built container to its registry."""
         if not self.is_built():
-            raise ContainerError("{} push failed: image not built".format(self.name))
+            raise ContainerError("{} push failed: image not built".format(self.tag))
         try:
             subprocess.check_call(['docker', 'push', self.tag], cwd=self.path)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} push failed: docker returned non-zero exit code")
+            msg = "{} push failed: docker returned non-zero exit code"
+            raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} push failed: docker is not available".format(self.tag))
 
     def remove(self):
         """
@@ -420,18 +434,10 @@ class Container(object):
         try:
             subprocess.check_call(['docker', 'rmi', self.tag], cwd=self.path)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} remove failed".format(self.tag))
-
-    def is_running(self):
-        """Return True if the container is running."""
-        try:
-            args = self._get_fig_args('ps', '-q')
-            out = subprocess.check_output(args, cwd=self.path).strip()
-            if out:
-                return True
-            return False
-        except subprocess.CalledProcessError:
-            raise ContainerError("{} running check failed")
+            msg = "{} remove failed: docker returned non-zero exit code"
+            raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} remove failed: docker is not available".format(self.tag))
 
     def run(self, detach=None):
         """
@@ -448,13 +454,18 @@ class Container(object):
             args = self._get_fig_args(*args)
             subprocess.check_call(args, cwd=self.path)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} run failed")
+            raise ContainerError("{} run failed: fig returned non-zero exit code".format(self.tag))
+        except OSError:
+            raise ContainerError("{} run failed: fig is not available".format(self.tag))
         except KeyboardInterrupt:
             pass
         finally:
             if not detach and self.allow_remove:
                 args = self._get_fig_args('rm', '--force', '-v')
-                subprocess.call(args, cwd=self.path)
+                try:
+                    subprocess.call(args, cwd=self.path)
+                except OSError:
+                    pass
 
     def kill(self):
         """
@@ -466,11 +477,17 @@ class Container(object):
                 args = self._get_fig_args('kill')
                 subprocess.check_call(args, cwd=self.path)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} kill failed")
+            msg = "{} kill failed: fig returned non-zero exit code"
+            raise ContainerError(msg.format(self.tag))
+        except OSError:
+            raise ContainerError("{} kill failed: fig is not available".format(self.tag))
         finally:
             if self.allow_remove:
                 args = self._get_fig_args('rm', '--force', '-v')
-                subprocess.call(args, cwd=self.path)
+                try:
+                    subprocess.call(args, cwd=self.path)
+                except OSError:
+                    pass
 
     def test(self, rebuild=None):
         """
@@ -491,13 +508,17 @@ class Container(object):
             except subprocess.CalledProcessError:
                 msg = "{} test failed: failed to rebuild test container"
                 raise ContainerError(msg.format(self.tag))
+            except OSError:
+                raise ContainerError("{} test failed: fig is not available".format(self.tag))
 
         try:
             services = set(self._get_fig_cfg(True).keys()) - {'test'}
             args = self._get_fig_args('up', '-d', *services)
             subprocess.check_call(args, cwd=self.path)
         except subprocess.CalledProcessError:
-            raise ContainerError("{} test failed: failed to start dependencies")
+            raise ContainerError("{} test failed: failed to start dependencies".format(self.tag))
+        except OSError:
+            raise ContainerError("{} test failed: fig is not available".format(self.tag))
 
         try:
             if self.allow_remove:
@@ -508,8 +529,7 @@ class Container(object):
             if exit_code != 0:
                 msg = "{} test failed: returned non-zero exit code {}"
                 raise TestError(msg.format(self.tag, exit_code), exit_code)
-
-        except KeyboardInterrupt:
-            raise ContainerError("{} test failed: interrupted".format(self.tag))
+        except OSError:
+            raise ContainerError("{} test failed: fig is not available".format(self.tag))
         finally:
             self.kill()
