@@ -29,8 +29,6 @@ def _script(container):
         return version or None
     except subprocess.CalledProcessError:
         raise VersionError("version script failed: command failed")
-    except KeyboardInterrupt:
-        raise VersionError("version script failed: interrupted")
 
 
 def _git_tag(container):
@@ -42,7 +40,7 @@ def _git_tag(container):
         if not lines or not lines[-1]:
             return None
         return lines[-1]
-    except subprocess.CalledProcessError:
+    except (subprocess.CalledProcessError, OSError):
         return None
 
 
@@ -52,10 +50,22 @@ def _git_rev(container):
         rev = subprocess.check_output(['git', 'rev-parse', '--verify', '--short', 'HEAD'],
                                       cwd=container.path, universal_newlines=True).strip()
         return 'rev-{}'.format(rev)
-    except subprocess.CalledProcessError:
+    except (subprocess.CalledProcessError, OSError):
         return None
 
 
+def _git_verify(container, tag):
+    """
+    Verify the container's tag. Return `True` on success else `False`. Raise `VersionError` on
+    failure.
+    """
+    try:
+        subprocess.check_call(['git', 'verify-tag', tag], cwd=container.path)
+        return True
+    except (subprocess.CalledProcessError, OSError):
+        return False
+
+
 def detect(container):
     """
     Detect the container version. Three methods are used to determine the version. They are execute
@@ -68,7 +78,7 @@ def detect(container):
 
     If the container path is part of a git repository and the git command exists the annotated tag
     of the current commit is returned. If the current commit has more than one tag they are sorted
-    suing a locale sensitive sort and the last item returned.
+    using a locale sensitive sort and the last item returned.
 
     If the current commit has no tag then the short form of the current git tag is appended to
     'rev-' to form a commit specific version. This step is skipped
@@ -85,3 +95,17 @@ def detect(container):
         if version is not None:
             return version
     return default_version
+
+
+def verify(container):
+    """
+    If a container is part of a git repository its contents may be verified. This retrieves the
+    current tag and verifies its GPG signature.
+
+    This check will fail for untagged commits, unsigned tags, if the container is not in a git
+    repository, or if the git command is missing. Raise `VersionError` on failure.
+    """
+    tag = _git_tag(container)
+    if not tag:
+        return False
+    return _git_verify(container, tag)
